# coding: utf8

ELFINDER_DEFAULT_OPTIONS = {
}

CKEDITOR_DEFAULT_OPTIONS = {
    'skin': 'bootstrapck',
    'preset': 'full',
    'filebrowserWindowWidth': 940,
    'filebrowserWindowHeight': 450,
    'language': 'ru',
}
